@@ -3,10 +3,10 @@
  *  Module    : nntplib.h
  *  Author    : I.Lea
  *  Created   : 1991-04-01
- *  Updated   : 2010-04-29
+ *  Updated   : 2015-11-16
  *  Notes     : nntp.h 1.5.11/1.6 with extensions for tin
  *
- * Copyright (c) 1991-2015 Iain Lea <iain@bricbrac.de>
+ * Copyright (c) 1991-2016 Iain Lea <iain@bricbrac.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -88,6 +88,7 @@
 #define OK_NOPOST		201	/* Hello; you can't post */
 #define OK_EXTENSIONS	202	/* extensions supported follow */
 #define OK_GOODBYE		205	/* Closing connection */
+#define OK_COMPRESS		206	/* Compression active */
 #define OK_GROUP		211	/* Group selected */
 #define OK_GROUPS		215	/* Newsgroups follow */
 #define OK_MOTD			215	/* News motd follows */
@@ -116,6 +117,7 @@
 
 #define ERR_GOODBYE		400	/* Have to hang up for some reason */
 #define ERR_STATE		401 /* The client must change the state of the connection */
+#define ERR_COMPRESS	403	/* Unable to activate compression */
 #define ERR_NOGROUP		411	/* No such newsgroup */
 #define ERR_NCING		412	/* Not currently in newsgroup */
 
@@ -139,6 +141,7 @@
 #define ERR_ACCESS		502	/* Access to server denied */
 #define ERR_FAULT		503	/* Program fault, command not performed */
 #define ERR_MOTD		503	/* No news motd file */
+#define ERR_COMPRESS_ALG	503	/* Compression algorithm not supported */
 #define ERR_AUTHBAD		580	/* Authorization Failed */
 
 /*
