@@ -3,10 +3,10 @@
  *  Module    : makecfg.c
  *  Author    : Thomas E. Dickey
  *  Created   : 1997-08-23
- *  Updated   : 2009-02-14
+ *  Updated   : 2015-11-25
  *  Notes     : #defines and structs for options_menu.c
  *
- * Copyright (c) 1997-2015 Thomas E. Dickey <dickey@invisible-island.net>
+ * Copyright (c) 1997-2016 Thomas E. Dickey <dickey@invisible-island.net>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -511,6 +511,7 @@ main(
 	FILE *input = stdin;
 	FILE *output = stdout;
 	FILE *output2 = open_it("options_menu.h", "w");
+	MYDATA *m, *n;
 
 	if (argc > 1)
 		input = open_it(argv[1], "r");
@@ -518,5 +519,14 @@ main(
 		output = open_it(argv[2], "w");
 	makecfg(input, output, output2);
 
+	m = all_data;
+	while (m) {
+		n = m->link;
+		FreeIfNeeded(m->name);
+		FreeIfNeeded(m->type);
+		free(m);
+		m = n;
+	}
+
 	return (0);
 }
